@@ -56,9 +56,6 @@
 #'   # if you assign results to an object, you can also look at the dataframe
 #'   as.data.frame(result)
 #' }
-#' @importFrom stats fitted sd complete.cases
-#' @importFrom insight get_data get_response find_response
-#'
 #' @export
 binned_residuals <- function(model, term = NULL, n_bins = NULL, ...) {
   fv <- stats::fitted(model)
@@ -70,7 +67,7 @@ binned_residuals <- function(model, term = NULL, n_bins = NULL, ...) {
     pred <- mf[[term]]
   }
 
-  y <- .recode_to_zero(insight::get_response(model)) - fv
+  y <- .recode_to_zero(insight::get_response(model, verbose = FALSE)) - fv
 
   if (is.null(n_bins)) n_bins <- round(sqrt(length(pred)))
 
