@@ -12,7 +12,7 @@
 #' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @details This test of the hypothesis of (non-)constant error is also called
-#' \emph{Breusch-Pagan test} (\cite{1979}).
+#'   \emph{Breusch-Pagan test} (\cite{1979}).
 #'
 #' @references Breusch, T. S., and Pagan, A. R. (1979) A simple test for heteroscedasticity and random coefficient variation. Econometrica 47, 1287–1294.
 #'
@@ -25,8 +25,6 @@
 #'   x <- check_heteroscedasticity(m)
 #'   plot(x)
 #' }
-#' @importFrom stats residuals df.residual fitted anova pchisq
-#' @importFrom insight print_color get_df format_p
 #' @export
 check_heteroscedasticity <- function(x, ...) {
   UseMethod("check_heteroscedasticity")
@@ -47,7 +45,7 @@ check_heteroscedasticity.default <- function(x, ...) {
     if (info$is_count) {
       paste0(msg, " You may check your model for overdispersion or zero-inflation instead (see 'check_overdispersion()' and 'check_zeroinflation()').")
     }
-    message(msg)
+    message(insight::format_message(msg))
     return(NULL)
   }
 
@@ -55,7 +53,7 @@ check_heteroscedasticity.default <- function(x, ...) {
   S.sq <- insight::get_df(x, type = "residual") * .sigma(x)^2 / sum(!is.na(r))
 
   .U <- (r^2) / S.sq
-  mod <- lm(.U ~ stats::fitted(x))
+  mod <- stats::lm(.U ~ stats::fitted(x))
 
   SS <- stats::anova(mod)$"Sum Sq"
   RegSS <- sum(SS) - SS[length(SS)]
@@ -76,8 +74,6 @@ check_heteroscedasticity.default <- function(x, ...) {
 }
 
 
-
-#' @importFrom insight get_parameters n_obs get_variance_residual get_deviance
 .sigma <- function(x) {
   s <- tryCatch(
     {
@@ -125,8 +121,6 @@ check_heteroscedasticity.default <- function(x, ...) {
 
 
 
-#' @importFrom insight get_response get_variance_distribution
-#' @importFrom stats predict family plogis
 .resid_zinb <- function(model, faminfo) {
   if (inherits(model, "glmmTMB")) {
     v <- stats::family(model)$variance
@@ -158,7 +152,7 @@ check_heteroscedasticity.default <- function(x, ...) {
   }
 
   # pearson residuals
-  (insight::get_response(model) - pred) / sqrt(pvar)
+  (insight::get_response(model, verbose = FALSE) - pred) / sqrt(pvar)
 }
 
 
