@@ -33,6 +33,12 @@
 #'   \item use some form of model selection to choose a model that balances predictive accuracy and overfitting/type I error (\cite{Bates et al. 2015}, \cite{Matuschek et al. 2017})
 #'   \item \dQuote{keep it maximal}, i.e. fit the most complex model consistent with the experimental design, removing only terms required to allow a non-singular fit (\cite{Barr et al. 2013})
 #'   }
+#'   Note the different meaning between singularity and convergence: singularity
+#'   indicates an issue with the "true" best estimate, i.e. whether the maximum
+#'   likelihood estimation for the variance-covariance matrix of the random effects
+#'   is positive definite or only semi-definite. Convergence is a question of
+#'   whether we can assume that the numerical optimization has worked correctly
+#'   or not.
 #'
 #' @references \itemize{
 #'   \item Bates D, Kliegl R, Vasishth S, Baayen H. Parsimonious Mixed Models. arXiv:1506.04967, June 2015.
@@ -42,23 +48,24 @@
 #'   }
 #'
 #' @examples
-#' library(lme4)
-#' data(sleepstudy)
-#' set.seed(123)
-#' sleepstudy$mygrp <- sample(1:5, size = 180, replace = TRUE)
-#' sleepstudy$mysubgrp <- NA
-#' for (i in 1:5) {
-#'   filter_group <- sleepstudy$mygrp == i
-#'   sleepstudy$mysubgrp[filter_group] <-
-#'     sample(1:30, size = sum(filter_group), replace = TRUE)
+#' if (require("lme4")) {
+#'   data(sleepstudy)
+#'   set.seed(123)
+#'   sleepstudy$mygrp <- sample(1:5, size = 180, replace = TRUE)
+#'   sleepstudy$mysubgrp <- NA
+#'   for (i in 1:5) {
+#'     filter_group <- sleepstudy$mygrp == i
+#'     sleepstudy$mysubgrp[filter_group] <-
+#'       sample(1:30, size = sum(filter_group), replace = TRUE)
+#'   }
+#'
+#'   model <- lmer(
+#'     Reaction ~ Days + (1 | mygrp / mysubgrp) + (1 | Subject),
+#'     data = sleepstudy
+#'   )
+#'
+#'   check_singularity(model)
 #' }
-#'
-#' model <- lmer(
-#'   Reaction ~ Days + (1 | mygrp / mysubgrp) + (1 | Subject),
-#'   data = sleepstudy
-#' )
-#'
-#' check_singularity(model)
 #' @export
 check_singularity <- function(x, tolerance = 1e-5, ...) {
   UseMethod("check_singularity")
@@ -111,6 +118,18 @@ check_singularity.clmm <- function(x, tolerance = 1e-5, ...) {
 
 
 
+#' @export
+check_singularity.cpglmm <- function(x, tolerance = 1e-5, ...) {
+  if (!requireNamespace("cplm", quietly = TRUE)) {
+    stop("Package `cplm` needed for this function to work. Please install it.")
+  }
+
+  vc <- cplm::VarCorr(x)
+  any(sapply(vc, function(.x) any(abs(diag(.x)) < tolerance)))
+}
+
+
+
 #' @export
 check_singularity.MixMod <- function(x, tolerance = 1e-5, ...) {
   any(sapply(diag(x$D), function(.x) any(abs(.x) < tolerance)))
@@ -118,7 +137,6 @@ check_singularity.MixMod <- function(x, tolerance = 1e-5, ...) {
 
 
 
-#' @importFrom stats na.omit
 #' @export
 check_singularity.lme <- function(x, tolerance = 1e-5, ...) {
   if (!requireNamespace("nlme", quietly = TRUE)) {
