@@ -4,6 +4,7 @@
 #' @description Calculates the pseudo-R2 value based on the proposal from \cite{Cox & Snell (1989)}.
 #'
 #' @param model Model with binary outcome.
+#' @param ... Currently not used.
 #'
 #' @details This index was proposed by \cite{Cox & Snell (1989, pp. 208-9)} and,
 #'   apparently independently, by \cite{Magee (1990)}; but had been suggested earlier
@@ -24,11 +25,8 @@
 #'   \item Maddala, G. S. (1986). Limited-dependent and qualitative variables in econometrics (No. 3). Cambridge university press.
 #'   \item Nagelkerke, N. J. (1991). A note on a general definition of the coefficient of determination. Biometrika, 78(3), 691-692.
 #' }
-#'
-#' @importFrom insight n_obs get_loglikelihood
-#' @importFrom stats update
 #' @export
-r2_coxsnell <- function(model) {
+r2_coxsnell <- function(model, ...) {
   UseMethod("r2_coxsnell")
 }
 
@@ -63,14 +61,22 @@ r2_coxsnell <- function(model) {
 
 
 #' @export
-r2_coxsnell.glm <- function(model) {
-  # if no deviance, return NA
-  if (is.null(model$deviance)) {
+r2_coxsnell.glm <- function(model, verbose = TRUE, ...) {
+  info <- insight::model_info(model)
+  if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
+    if (verbose) {
+      warning(insight::format_message("Can't calculate accurate R2 for binomial models that are not Bernoulli models."), call. = FALSE)
+    }
     return(NULL)
+  } else {
+    # if no deviance, return NA
+    if (is.null(model$deviance)) {
+      return(NULL)
+    }
+    r2_coxsnell <- (1 - exp((model$deviance - model$null.deviance) / insight::n_obs(model)))
+    names(r2_coxsnell) <- "Cox & Snell's R2"
+    r2_coxsnell
   }
-  r2_coxsnell <- (1 - exp((model$deviance - model$null.deviance) / insight::n_obs(model)))
-  names(r2_coxsnell) <- "Cox & Snell's R2"
-  r2_coxsnell
 }
 
 #' @export
@@ -80,7 +86,7 @@ r2_coxsnell.BBreg <- r2_coxsnell.glm
 r2_coxsnell.mclogit <- r2_coxsnell.glm
 
 #' @export
-r2_coxsnell.bife <- function(model) {
+r2_coxsnell.bife <- function(model, ...) {
   r2_coxsnell <- (1 - exp((model$deviance - model$null_deviance) / insight::n_obs(model)))
   names(r2_coxsnell) <- "Cox & Snell's R2"
   r2_coxsnell
@@ -96,7 +102,7 @@ r2_coxsnell.bife <- function(model) {
 
 #' @export
 r2_coxsnell.logitmfx <- function(model, ...) {
-  r2(model$fit, ...)
+  r2_coxsnell(model$fit, ...)
 }
 
 #' @export
@@ -128,7 +134,7 @@ r2_coxsnell.negbinmfx <- r2_coxsnell.logitmfx
 
 
 #' @export
-r2_coxsnell.coxph <- function(model) {
+r2_coxsnell.coxph <- function(model, ...) {
   l_base <- model$loglik[1]
   .r2_coxsnell(model, l_base)
 }
@@ -137,7 +143,7 @@ r2_coxsnell.coxph <- function(model) {
 r2_coxsnell.survreg <- r2_coxsnell.coxph
 
 #' @export
-r2_coxsnell.svycoxph <- function(model) {
+r2_coxsnell.svycoxph <- function(model, ...) {
   l_base <- model$ll[1]
   .r2_coxsnell(model, l_base)
 }
@@ -151,26 +157,25 @@ r2_coxsnell.svycoxph <- function(model) {
 
 
 #' @export
-r2_coxsnell.multinom <- function(model) {
+r2_coxsnell.multinom <- function(model, ...) {
   l_base <- insight::get_loglikelihood(stats::update(model, ~1, trace = FALSE))
   .r2_coxsnell(model, l_base)
 }
 
 #' @export
-r2_coxsnell.clm2 <- function(model) {
+r2_coxsnell.clm2 <- function(model, ...) {
   l_base <- insight::get_loglikelihood(stats::update(model, location = ~1, scale = ~1))
   .r2_coxsnell(model, l_base)
 }
 
-#' @importFrom utils capture.output
 #' @export
-r2_coxsnell.bayesx <- function(model) {
+r2_coxsnell.bayesx <- function(model, ...) {
   junk <- utils::capture.output(l_base <- insight::get_loglikelihood(stats::update(model, ~1)))
   .r2_coxsnell(model, l_base)
 }
 
 #' @export
-r2_coxsnell.clm <- function(model) {
+r2_coxsnell.clm <- function(model, ...) {
   l_base <- insight::get_loglikelihood(stats::update(model, ~1))
   # if no loglik, return NA
   if (length(as.numeric(l_base)) == 0) {
