@@ -17,7 +17,7 @@ if (require("testthat") && require("performance") && require("glmmTMB")) {
       c(1.00037354840318, 1.00037354840318),
       tolerance = 1e-3
     )
-    expect_null(check_collinearity(m1, component = "zero_inflated"))
+    expect_null(check_collinearity(m1, component = "zero_inflated", verbose = FALSE))
   })
 
   m2 <- glmmTMB(
@@ -44,4 +44,33 @@ if (require("testthat") && require("performance") && require("glmmTMB")) {
       tolerance = 1e-3
     )
   })
+
+  test_that("check_collinearity | afex", {
+    skip_if_not_installed("afex")
+
+    data(obk.long, package = "afex")
+
+    obk.long$treatment <- as.character(obk.long$treatment)
+    suppressWarnings(suppressMessages({
+      aM <- afex::aov_car(value ~ treatment * gender + Error(id / (phase * hour)),
+        data = obk.long
+      )
+
+      aW <- afex::aov_car(value ~ Error(id / (phase * hour)),
+        data = obk.long
+      )
+
+      aB <- afex::aov_car(value ~ treatment * gender + Error(id),
+        data = obk.long
+      )
+    }))
+
+    expect_message(ccoM <- check_collinearity(aM))
+    expect_message(ccoW <- check_collinearity(aW))
+    expect_message(ccoB <- check_collinearity(aB))
+
+    expect_equal(nrow(ccoM), 15)
+    expect_equal(nrow(ccoW), 3)
+    expect_equal(nrow(ccoB), 3)
+  })
 }
