@@ -1,9 +1,7 @@
-if (require("testthat") && require("performance")) {
+if (require("testthat") && require("performance") && require("lme4")) {
   .runThisTest <- Sys.getenv("RunAllperformanceTests") == "yes"
 
   if (.runThisTest) {
-    context("model_performance.merMod")
-
     test_that("model_performance.merMod", {
       library(insight)
 
